import pkg_resources

__cached = None

def get_environment():
    global __cached
    if __cached is None:
        __cached = [
        {"name": str(pkg.project_name), "path": str(pkg.location), "version": str(pkg.parsed_version) } for pkg in pkg_resources.working_set
    ]
    return __cached


"""
Provide some simple functions for printing the context.
"""

import os
import sys
import typing
from datetime import datetime


def print_readme(line_limit: typing.Optional[int] = None):
    if not os.path.exists("./README.md"):
        print("No README.md")
        return
    with open("./README.md", "r") as f:
        for i, l in enumerate(f.readlines()):
            if line_limit and i == l:
                return
            print(l.rstrip())


def print_context():
    print("CWD:", os.getcwd())
    print("ARGV:", sys.argv)
    print("Time:", datetime.now().strftime("%Y-%m-%d %H:%M:%S"))



import io
import typing


class OutputCopy(io.StringIO):
    def __init__(self, wrap):
        super().__init__()
        self.wrapped_stream = wrap

    def write(self, __s: str) -> int:
        ret = super().write(__s)
        self.wrapped_stream.write(__s)
        return ret

    def writelines(self, __lines: typing.Iterable[str]) -> None:
        __lines = list(__lines)
        ret = super().writelines(__lines)
        self.wrapped_stream.writelines(__lines)
        return ret



"""
This file is internal for creating a proper package.

Build package with `python3 setup.py sdist bdist_wheel`
Upload with `python3 -m twine upload dist/aemeasure-X.X.X-py3-none-any.whl `

"""

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="aemeasure",
    version="0.2.9",
    author="TU Braunschweig, IBR, Algorithms Group (Dominik Krupke)",
    author_email="krupke@ibr.cs.tu-bs.de",
    description="Simple tools for logging experiments in algorithm engineering",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/d-krupke/AeMeasure",
    packages=[p for p in setuptools.find_packages() if "aemeasure" in p],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Development Status :: 3 - Alpha",
    ],
    python_requires=">=3.7",
    install_requires=["pandas"],
)
